@@ -1,9 +1,6 @@
 require 'chunky_png'
 
 module OilyPNG
-  
-  VERSION = "1.1.0"
-
   def self.included(base)
     base::Canvas.send(:extend, OilyPNG::PNGDecoding)
     base::Canvas.send(:include, OilyPNG::PNGEncoding)
@@ -13,9 +10,11 @@ module OilyPNG
     
     base::Color.extend OilyPNG::Color
     base::Canvas.send(:include, OilyPNG::Resampling)
+    base::Canvas.send(:include, OilyPNG::Operations)
   end
 end
 
+require 'oily_png/version'
 require 'oily_png/oily_png'
 require 'oily_png/canvas'
 
